# fklearn: Functional Machine Learning

![PyPI](https://img.shields.io/pypi/v/fklearn.svg?style=flat-square)
[![Documentation Status](https://readthedocs.org/projects/fklearn/badge/?version=latest)](https://fklearn.readthedocs.io/en/latest/?badge=latest)
[![Gitter](https://badges.gitter.im/fklearn-python/community.svg)](https://gitter.im/fklearn-python/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![CircleCI](https://circleci.com/gh/nubank/fklearn.svg?style=svg)](https://circleci.com/gh/nubank/fklearn)
[![codecov.io](https://codecov.io/github/nubank/fklearn/branch/master/graph/badge.svg)](https://codecov.io/github/nubank/fklearn)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

**fklearn** uses functional programming principles to make it easier to solve real problems with Machine Learning.

The name is a reference to the widely known [scikit-learn](https://scikit-learn.org/stable/) library.

**fklearn Principles**

1. Validation should reflect real-life situations.
2. Production models should match validated models.
3. Models should be production-ready with few extra steps.
4. Reproducibility and in-depth analysis of model results should be easy to achieve.


[Documentation](https://fklearn.readthedocs.io/en/latest/) |
[Getting Started](https://fklearn.readthedocs.io/en/latest/getting_started.html) |
[API Docs](https://fklearn.readthedocs.io/en/latest/api.html) |
[Contributing](https://fklearn.readthedocs.io/en/latest/contributing.html) |


## Installation

To install via pip:

```
pip install fklearn
```

You can also install from the source:

```sh
git clone git@github.com:nubank/fklearn.git
cd fklearn
git checkout master
pip install -e .
```

## License

[Apache License 2.0](LICENSE)
